==> snf-cloudcms-0.7.0.tar.gz: snf-cloudcms-0.7.0/cloudcms/tests/__init__.py <==
# Copyright 2012 GRNET S.A. All rights reserved.
#
# Redistribution and use in source and binary forms, with or
# without modification, are permitted provided that the following
# conditions are met:
#
#   1. Redistributions of source code must retain the above
#      copyright notice, this list of conditions and the following
#      disclaimer.
#
#   2. Redistributions in binary form must reproduce the above
#      copyright notice, this list of conditions and the following
#      disclaimer in the documentation and/or other materials
#      provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY GRNET S.A. ``AS IS'' AND ANY EXPRESS
# OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL GRNET S.A OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
# USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
# AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.
#
# The views and conclusions contained in the software and
# documentation are those of the authors and should not be
# interpreted as representing official policies, either expressed
# or implied, of GRNET S.A.


import os
import tempfile

from django.test import TestCase, TransactionTestCase
from django.contrib.auth.models import User
from django.core.files.uploadedfile import SimpleUploadedFile

from feincms.module.medialibrary.models import Category as MediaCategory, \
        MediaFile

from cloudcmsguide.models import UserGuideEntry
from cloudcmsfaq.models import Category, Question
from cloudcms.rstutils import generate_rst_contents_from_dir
from cloudcms.models import Service, ServiceTranslation
from cloudcms.forms import RstZipImportForm

from synnefo.lib.log import initialize_logging

from django.conf import settings

initialize_logging()

TESTS_BASE = os.path.abspath(os.path.dirname(__file__))

TEST_DIR1 = os.path.join(TESTS_BASE, 'userdocs1')
TEST_DIR2 = os.path.join(TESTS_BASE, 'userdocs2')

TEST_INVALID_ZIP = os.path.join(TESTS_BASE, 'invalidzip.zip')
TEST_VALID_ZIP = os.path.join(TESTS_BASE, 'okeanos-user-docs.zip')
TEST_VALID_ZIP = os.path.join(TESTS_BASE, 'userdocs1.zip')

settings.MEDIA_ROOT = tempfile.mkdtemp("cms-tests")

class TestSphinxImport(TransactionTestCase):

    fixtures = ['cloudcms_media_categories', 'cloudcms_default_services']

    def setUp(self):
        c = Category.objects.create()
        self.user = User.objects.create(username="admin", email="admin@admin.com")
        self.user.is_superuser = True
        self.user.set_password("test")
        self.user.save()

    def test_from_dir1(self):
        zipfile = SimpleUploadedFile('file.zip', file(TEST_VALID_ZIP).read())
        form = RstZipImportForm({'import_categories': ['faqs', 'guide']}, files={'import_file': zipfile})
        form.is_valid()
        success, log = form.save(self.user, TEST_DIR1)

        self.assertEqual(success, True)
        self.assertEqual(MediaFile.objects.all().count(), 3)
        self.assertEqual(Question.objects.all().count(), 4)
        self.assertEqual(UserGuideEntry.objects.all().count(), 3)

    def test_form(self):
        zipfile = SimpleUploadedFile('file.zip', file(TEST_INVALID_ZIP).read())
        form = RstZipImportForm({'import_categories': ['faqs', 'guide']}, files={'import_file': zipfile})
        self.assertEqual(form.is_valid(), False)

        zipfile = SimpleUploadedFile('file.zip', file(TEST_VALID_ZIP).read())
        form = RstZipImportForm({'import_categories': ['faqs', 'guide']}, files={'import_file': zipfile})
        self.assertEqual(form.is_valid(), True)

        form.save(self.user)
        self.assertEqual(MediaFile.objects.all().count(), 5)
        self.assertEqual(Question.objects.all().count(), 4)
        self.assertEqual(UserGuideEntry.objects.all().count(), 3)

==> snf-cloudcms_0.15.orig.tar.gz: snf-cloudcms-0.15/cloudcms/tests/__init__.py <==
# Copyright 2012 GRNET S.A. All rights reserved.
#
# Redistribution and use in source and binary forms, with or
# without modification, are permitted provided that the following
# conditions are met:
#
#   1. Redistributions of source code must retain the above
#      copyright notice, this list of conditions and the following
#      disclaimer.
#
#   2. Redistributions in binary form must reproduce the above
#      copyright notice, this list of conditions and the following
#      disclaimer in the documentation and/or other materials
#      provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY GRNET S.A. ``AS IS'' AND ANY EXPRESS
# OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL GRNET S.A OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
# USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
# AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.
#
# The views and conclusions contained in the software and
# documentation are those of the authors and should not be
# interpreted as representing official policies, either expressed
# or implied, of GRNET S.A.


import os
import tempfile

from django.test import TransactionTestCase
from django.contrib.auth.models import User
from django.core.files.uploadedfile import SimpleUploadedFile

from feincms.module.medialibrary.models import MediaFile

from cloudcmsguide.models import UserGuideEntry
from cloudcmsfaq.models import Question
from cloudcms.forms import RstZipImportForm

from django.conf import settings


TESTS_BASE = os.path.abspath(os.path.dirname(__file__))

TEST_DIR1 = os.path.join(TESTS_BASE, 'userdocs1')
TEST_DIR2 = os.path.join(TESTS_BASE, 'userdocs2')

TEST_INVALID_ZIP = os.path.join(TESTS_BASE, 'invalidzip.zip')
TEST_VALID_ZIP = os.path.join(TESTS_BASE, 'okeanos-user-docs.zip')
TEST_VALID_ZIP = os.path.join(TESTS_BASE, 'userdocs1.zip')

settings.MEDIA_ROOT = tempfile.mkdtemp("cms-tests")


class TestSphinxImport(TransactionTestCase):

    fixtures = ['cloudcms_media_categories', 'cloudcms_default_services']

    def setUp(self):
        self.user = User.objects.create(username="admin",
                                        email="admin@admin.com")
        self.user.is_superuser = True
        self.user.set_password("test")
        self.user.save()

    def test_from_dir1(self):
        zipfile = SimpleUploadedFile('file.zip', file(TEST_VALID_ZIP).read())
        form = RstZipImportForm({
            'import_categories': ['faqs', 'guide']
        }, files={'import_file': zipfile})
        form.is_valid()
        success, log = form.save(self.user, TEST_DIR1)

        self.assertEqual(success, True)
        self.assertEqual(MediaFile.objects.all().count(), 3)
        self.assertEqual(Question.objects.all().count(), 4)
        self.assertEqual(UserGuideEntry.objects.all().count(), 3)

    def test_form(self):
        zipfile = SimpleUploadedFile('file.zip', file(TEST_INVALID_ZIP).read())
        form = RstZipImportForm({
            'import_categories': ['faqs', 'guide']},
            files={'import_file': zipfile})
        self.assertEqual(form.is_valid(), False)

        zipfile = SimpleUploadedFile('file.zip', file(TEST_VALID_ZIP).read())
        form = RstZipImportForm({
            'import_categories': ['faqs', 'guide']},
            files={'import_file': zipfile})
        self.assertEqual(form.is_valid(), True)

        form.save(self.user)
        self.assertEqual(MediaFile.objects.all().count(), 3)
        self.assertEqual(Question.objects.all().count(), 4)
        self.assertEqual(UserGuideEntry.objects.all().count(), 3)
